@@ -24,13 +24,13 @@ using namespace MailCommon;
 CollectionViewWidget::CollectionViewWidget(QWidget *parent)
     : QWidget(parent)
     , mShowSenderReceiverComboBox(new QComboBox(this))
-    , mUseDefaultAggregationCheckBox(new QCheckBox(i18n("Use default message list aggregation:"), this))
+    , mUseDefaultAggregationCheckBox(new QCheckBox(i18nc("@option:check", "Use default message list aggregation:"), this))
     , mAggregationComboBox(new MessageList::Utils::AggregationComboBox(this))
-    , mUseDefaultThemeCheckBox(new QCheckBox(i18n("Use default message list theme"), this))
+    , mUseDefaultThemeCheckBox(new QCheckBox(i18nc("@option:check", "Use default message list theme"), this))
     , mThemeComboBox(new MessageList::Utils::ThemeComboBox(this))
-    , mPreferHtmlToText(new QRadioButton(i18n("Prefer HTML to text"), this))
-    , mPreferTextToHtml(new QRadioButton(i18n("Prefer text to HTML"), this))
-    , mUseGlobalSettings(new QRadioButton(i18n("Use Global Settings"), this))
+    , mPreferHtmlToText(new QRadioButton(i18nc("@option:radio", "Prefer HTML to text"), this))
+    , mPreferTextToHtml(new QRadioButton(i18nc("@option:radio", "Prefer text to HTML"), this))
+    , mUseGlobalSettings(new QRadioButton(i18nc("@option:radio", "Use Global Settings"), this))
 {
     auto topLayout = new QFormLayout(this);
     topLayout->setObjectName(QLatin1StringView("topLayout"));
@@ -46,11 +46,7 @@ CollectionViewWidget::CollectionViewWidget(QWidget *parent)
     topLayout->addRow(i18n("Sho&w column:"), mShowSenderReceiverComboBox);
 
     // message list aggregation
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mUseDefaultAggregationCheckBox, &QCheckBox::stateChanged, this, &CollectionViewWidget::slotAggregationCheckboxChanged);
-#else
     connect(mUseDefaultAggregationCheckBox, &QCheckBox::checkStateChanged, this, &CollectionViewWidget::slotAggregationCheckboxChanged);
-#endif
     topLayout->addRow(QString(), mUseDefaultAggregationCheckBox);
 
     using MessageList::Utils::AggregationConfigButton;
@@ -64,11 +60,7 @@ CollectionViewWidget::CollectionViewWidget(QWidget *parent)
     topLayout->addRow(QString(), aggregationLayout);
 
     // message list theme
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(mUseDefaultThemeCheckBox, &QCheckBox::stateChanged, this, &CollectionViewWidget::slotThemeCheckboxChanged);
-#else
     connect(mUseDefaultThemeCheckBox, &QCheckBox::checkStateChanged, this, &CollectionViewWidget::slotThemeCheckboxChanged);
-#endif
     topLayout->addRow(QString(), mUseDefaultThemeCheckBox);
 
     using MessageList::Utils::ThemeConfigButton;
