@@ -4,8 +4,7 @@
  *  SPDX-License-Identifier: GPL-2.0-only
  */
 
-#ifndef FILTERACTIONDECRYPTTEST_H_
-#define FILTERACTIONDECRYPTTEST_H_
+#pragma once
 
 #include <QObject>
 
@@ -24,5 +23,3 @@ private Q_SLOTS:
 private:
     GPGHelper *mGpg = {};
 };
-
-#endif
