@@ -15,7 +15,7 @@ FilterActionPipeThroughTest::FilterActionPipeThroughTest() = default;
 void FilterActionPipeThroughTest::setOutput(FilterAction *filter, const QByteArray &output)
 {
     QByteArray sendData = output;
-    filter->argsFromString(QLatin1String("echo \"") + QString::fromUtf8(sendData.replace('"', "\\\"")) + QStringLiteral("\""));
+    filter->argsFromString(QLatin1StringView("echo \"") + QString::fromUtf8(sendData.replace('"', "\\\"")) + QStringLiteral("\""));
 }
 
 void FilterActionPipeThroughTest::testWithNoCommand()
@@ -29,7 +29,7 @@ void FilterActionPipeThroughTest::testWithNoCommand()
     item.setPayload<KMime::Message::Ptr>(msgPtr);
     ItemContext context(item, true);
 
-    filter.argsFromString(QLatin1String(""));
+    filter.argsFromString(QLatin1StringView(""));
     QCOMPARE(filter.process(context, false), FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
 }
