@@ -22,12 +22,12 @@ class FilterActionCopy : public FilterActionWithFolder
     Q_OBJECT
 public:
     explicit FilterActionCopy(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
     static FilterAction *newAction();
-    Q_REQUIRED_RESULT QString sieveCode() const override;
-    Q_REQUIRED_RESULT QStringList sieveRequires() const override;
-    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
+    [[nodiscard]] QString sieveCode() const override;
+    [[nodiscard]] QStringList sieveRequires() const override;
+    [[nodiscard]] QString informationAboutNotValidAction() const override;
 
 protected Q_SLOTS:
     void jobFinished(KJob *job);
