@@ -33,7 +33,7 @@ SearchRule::RequiredPart FilterActionDelete::requiredPart() const
 QWidget *FilterActionDelete::createParamWidget(QWidget *parent) const
 {
     auto lab = new QLabel(parent);
-    lab->setObjectName(QStringLiteral("label_delete"));
+    lab->setObjectName(QLatin1StringView("label_delete"));
     QPalette pal = lab->palette();
     KColorScheme scheme(QPalette::Active, KColorScheme::View);
     pal.setColor(QPalette::WindowText, scheme.foreground(KColorScheme::NegativeText).color());
