@@ -5,8 +5,7 @@
  *
  */
 
-#ifndef MAILCOMMON_FILTERACTIONDELETE_H
-#define MAILCOMMON_FILTERACTIONDELETE_H
+#pragma once
 
 #include "filteractionwithnone.h"
 
@@ -20,12 +19,10 @@ class FilterActionDelete : public FilterActionWithNone
     Q_OBJECT
 public:
     explicit FilterActionDelete(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
     static FilterAction *newAction();
-    Q_REQUIRED_RESULT QWidget *createParamWidget(QWidget *parent) const override;
-    Q_REQUIRED_RESULT QString sieveCode() const override;
+    [[nodiscard]] QWidget *createParamWidget(QWidget *parent) const override;
+    [[nodiscard]] QString sieveCode() const override;
 };
 }
-
-#endif
