@@ -20,10 +20,10 @@ class FilterActionRedirect : public FilterActionWithAddress
     Q_OBJECT
 public:
     explicit FilterActionRedirect(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
     static FilterAction *newAction();
-    Q_REQUIRED_RESULT QString sieveCode() const override;
-    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
+    [[nodiscard]] QString sieveCode() const override;
+    [[nodiscard]] QString informationAboutNotValidAction() const override;
 };
 }
