@@ -20,16 +20,16 @@ class FilterActionSendFakeDisposition : public FilterActionWithStringList
     Q_OBJECT
 public:
     explicit FilterActionSendFakeDisposition(QObject *parent = nullptr);
-    Q_REQUIRED_RESULT ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
-    Q_REQUIRED_RESULT SearchRule::RequiredPart requiredPart() const override;
+    [[nodiscard]] ReturnCode process(ItemContext &context, bool applyOnOutbound) const override;
+    [[nodiscard]] SearchRule::RequiredPart requiredPart() const override;
 
     static FilterAction *newAction();
 
-    Q_REQUIRED_RESULT bool isEmpty() const override;
+    [[nodiscard]] bool isEmpty() const override;
 
     void argsFromString(const QString &argsStr) override;
-    Q_REQUIRED_RESULT QString argsAsString() const override;
-    Q_REQUIRED_RESULT QString displayString() const override;
-    Q_REQUIRED_RESULT QString informationAboutNotValidAction() const override;
+    [[nodiscard]] QString argsAsString() const override;
+    [[nodiscard]] QString displayString() const override;
+    [[nodiscard]] QString informationAboutNotValidAction() const override;
 };
 }
