@@ -19,7 +19,7 @@ using namespace MailCommon;
 FilterActionWithUrlHelpButton::FilterActionWithUrlHelpButton(QWidget *parent)
     : QToolButton(parent)
 {
-    setToolTip(i18n("Help"));
+    setToolTip(i18nc("@info:tooltip", "Help"));
     setIcon(QIcon::fromTheme(QStringLiteral("help-hint")));
 }
 
