@@ -41,7 +41,7 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
     auto saveButton = new QPushButton(this);
     buttonBox->addButton(saveButton, QDialogButtonBox::ActionRole);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &FilterConvertToSieveResultDialog::reject);
-    saveButton->setText(i18n("Save..."));
+    saveButton->setText(i18n("Save…"));
     saveButton->setIcon(QIcon::fromTheme("document-save"));
     saveButton->setObjectName(QLatin1StringView("savebutton"));
     saveButton->setDefault(true);
@@ -64,7 +64,7 @@ FilterConvertToSieveResultDialog::FilterConvertToSieveResultDialog(QWidget *pare
             &FilterconverttosievePurposeMenuWidget::shareSuccess,
             mPurposeMenuMessageWidget,
             &PimCommon::PurposeMenuMessageWidget::slotShareSuccess);
-    auto shareButton = new QPushButton(i18n("Share..."), this);
+    auto shareButton = new QPushButton(i18nc("@action:button", "Share…"), this);
     shareButton->setMenu(purposeMenu->menu());
     shareButton->setIcon(QIcon::fromTheme(QStringLiteral("document-share")));
     purposeMenu->setEditorWidget(mEditor->editor());
