@@ -190,7 +190,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
     mAdvOptsGroup->setContentsMargins({});
     {
         auto gl = new QGridLayout();
-        mApplyOnIn = new QCheckBox(i18n("Apply this filter to incoming messages:"), mAdvOptsGroup);
+        mApplyOnIn = new QCheckBox(i18nc("@option:check", "Apply this filter to incoming messages:"), mAdvOptsGroup);
         gl->addWidget(mApplyOnIn, 0, 0);
 
         auto radioGroupWidget = new QWidget(page2);
@@ -200,15 +200,15 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
 
         auto bg = new QButtonGroup(mAdvOptsGroup);
 
-        mApplyOnForAll = new QRadioButton(i18n("From all accounts"), radioGroupWidget);
+        mApplyOnForAll = new QRadioButton(i18nc("@option:radio", "From all accounts"), radioGroupWidget);
         bg->addButton(mApplyOnForAll);
         vbl3->addWidget(mApplyOnForAll);
 
-        mApplyOnForTraditional = new QRadioButton(i18n("From all but online IMAP accounts"), radioGroupWidget);
+        mApplyOnForTraditional = new QRadioButton(i18nc("@option:radio", "From all but online IMAP accounts"), radioGroupWidget);
         bg->addButton(mApplyOnForTraditional);
         vbl3->addWidget(mApplyOnForTraditional);
 
-        mApplyOnForChecked = new QRadioButton(i18n("From selected accounts only"), radioGroupWidget);
+        mApplyOnForChecked = new QRadioButton(i18nc("@option:radio", "From selected accounts only"), radioGroupWidget);
         bg->addButton(mApplyOnForChecked);
         vbl3->addWidget(mApplyOnForChecked);
         vbl3->addStretch(100);
@@ -216,7 +216,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
         mAccountList = new KMFilterAccountList(mAdvOptsGroup);
         gl->addWidget(mAccountList, 0, 1, 4, 3);
 
-        mApplyOnOut = new QCheckBox(i18n("Apply this filter to &sent messages"), mAdvOptsGroup);
+        mApplyOnOut = new QCheckBox(i18nc("@option:check", "Apply this filter to &sent messages"), mAdvOptsGroup);
         mApplyOnOut->setToolTip(
             i18n("<p>The filter will be triggered <b>after</b> the message is sent "
                  "and it will only affect the local copy of the message.</p>"
@@ -224,17 +224,17 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
                  "please use \"Apply this filter <b>before</b> sending messages\".</p>"));
         gl->addWidget(mApplyOnOut, 5, 0, 1, 4);
 
-        mApplyBeforeOut = new QCheckBox(i18n("Apply this filter &before sending messages"), mAdvOptsGroup);
+        mApplyBeforeOut = new QCheckBox(i18nc("@option:check", "Apply this filter &before sending messages"), mAdvOptsGroup);
         mApplyBeforeOut->setToolTip(
             i18n("<p>The filter will be triggered <b>before</b> the message is sent "
                  "and it will affect both the local copy and the sent copy of the message.</p>"
                  "<p>This is required if the recipient's copy also needs to be modified.</p>"));
         gl->addWidget(mApplyBeforeOut, 6, 0, 1, 4);
 
-        mApplyOnCtrlJ = new QCheckBox(i18n("Apply this filter on manual &filtering"), mAdvOptsGroup);
+        mApplyOnCtrlJ = new QCheckBox(i18nc("@option:check", "Apply this filter on manual &filtering"), mAdvOptsGroup);
         gl->addWidget(mApplyOnCtrlJ, 7, 0, 1, 4);
 
-        mApplyOnAllFolders = new QCheckBox(i18n("Apply this filter on inbound emails in all folders"), mAdvOptsGroup);
+        mApplyOnAllFolders = new QCheckBox(i18nc("@option:check", "Apply this filter on inbound emails in all folders"), mAdvOptsGroup);
         mApplyOnAllFolders->setToolTip(
             i18n("<p>The filter will be applied on inbound emails from all folders "
                  "belonging to all accounts selected above. This is useful when using local filters "
@@ -242,10 +242,10 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
                  "by server-side filters.</p>"));
         gl->addWidget(mApplyOnAllFolders, 8, 0, 1, 4);
 
-        mStopProcessingHere = new QCheckBox(i18n("If this filter &matches, stop processing here"), mAdvOptsGroup);
+        mStopProcessingHere = new QCheckBox(i18nc("@option:check", "If this filter &matches, stop processing here"), mAdvOptsGroup);
         gl->addWidget(mStopProcessingHere, 9, 0, 1, 4);
 
-        mConfigureShortcut = new QCheckBox(i18n("Add this filter to the Apply Filter menu"), mAdvOptsGroup);
+        mConfigureShortcut = new QCheckBox(i18nc("@option:check", "Add this filter to the Apply Filter menu"), mAdvOptsGroup);
         gl->addWidget(mConfigureShortcut, 10, 0, 1, 2);
 
         mInMenuWidget = new QWidget(mAdvOptsGroup);
@@ -263,7 +263,7 @@ KMFilterDialog::KMFilterDialog(const QList<KActionCollection *> &actionCollectio
             }
         });
 
-        mConfigureToolbar = new QCheckBox(i18n("Additionally add this filter to the toolbar"), mInMenuWidget);
+        mConfigureToolbar = new QCheckBox(i18nc("@option:check", "Additionally add this filter to the toolbar"), mInMenuWidget);
         inMenuLayout->addRow(mConfigureToolbar);
 
         mKeySeqWidget = new KKeySequenceWidget(mInMenuWidget);
@@ -416,7 +416,9 @@ void KMFilterDialog::slotFolderChanged(const Akonadi::Collection &collection)
 void KMFilterDialog::slotRunFilters()
 {
     if (!mFolderRequester->collection().isValid()) {
-        KMessageBox::information(this, i18nc("@info", "Unable to apply this filter since there are no folders selected."), i18n("No folder selected."));
+        KMessageBox::information(this,
+                                 i18nc("@info", "Unable to apply this filter since there are no folders selected."),
+                                 i18nc("@title:window", "No folder selected."));
         return;
     }
 
@@ -425,13 +427,15 @@ void KMFilterDialog::slotRunFilters()
                                  i18nc("@info",
                                        "Some filters were changed and not saved yet. "
                                        "You must save your filters before they can be applied."),
-                                 i18n("Filters changed."));
+                                 i18nc("@title:window", "Filters changed."));
         return;
     }
     SearchRule::RequiredPart requiredPart = SearchRule::Envelope;
     const QStringList selectedFiltersId = mFilterList->selectedFilterId(requiredPart, mFolderRequester->collection().resource());
     if (selectedFiltersId.isEmpty()) {
-        KMessageBox::information(this, i18nc("@info", "Unable to apply a filter since there are no filters currently selected."), i18n("No filters selected."));
+        KMessageBox::information(this,
+                                 i18nc("@info", "Unable to apply a filter since there are no filters currently selected."),
+                                 i18nc("@title:window", "No filters selected."));
         return;
     }
     auto job = new Akonadi::ItemFetchJob(mFolderRequester->collection(), this);
@@ -705,12 +709,12 @@ void KMFilterDialog::slotExportAsSieveScript()
                                  i18nc("@info",
                                        "Some filters were changed and not saved yet.<br>"
                                        "You must save your filters before they can be exported."),
-                                 i18n("Filters changed."));
+                                 i18nc("@title:window", "Filters changed."));
         return;
     }
     KMessageBox::information(this,
                              i18n("We cannot convert all KMail filters to sieve scripts but we can try :)"),
-                             i18n("Convert KMail filters to sieve scripts"));
+                             i18nc("@title:window", "Convert KMail filters to sieve scripts"));
     bool wasCanceled = false;
     const QList<MailFilter *> filters = mFilterList->filtersForSaving(false, wasCanceled);
     if (filters.isEmpty()) {
@@ -726,7 +730,7 @@ void KMFilterDialog::slotExportAsSieveScript()
                 convert.convert();
                 qDeleteAll(lst);
             } else {
-                KMessageBox::information(this, i18n("No filters selected."), i18n("Convert KMail filters to sieve scripts"));
+                KMessageBox::information(this, i18n("No filters selected."), i18nc("@title:window", "Convert KMail filters to sieve scripts"));
             }
         }
         delete dlg;
