@@ -56,14 +56,14 @@ FolderSelectionDialog::FolderSelectionDialog(QWidget *parent, SelectionFolderOpt
     connect(buttonBox, &QDialogButtonBox::rejected, this, &FolderSelectionDialog::reject);
 
     if (!d->mNotAllowToCreateNewFolder) {
-        d->mUser1Button = new QPushButton;
+        d->mUser1Button = new QPushButton(this);
         d->mUser1Button->setDefault(false);
         d->mUser1Button->setAutoDefault(false);
         buttonBox->addButton(d->mUser1Button, QDialogButtonBox::ActionRole);
         KGuiItem::assign(d->mUser1Button,
                          KGuiItem(i18nc("@action:button", "&New Subfolder…"),
                                   QStringLiteral("folder-new"),
-                                  i18n("Create a new subfolder under the currently selected folder")));
+                                  i18nc("@info:tooltip", "Create a new subfolder under the currently selected folder")));
     }
     FolderTreeWidget::TreeViewOptions opt = FolderTreeWidget::None;
     if (options & FolderSelectionDialog::ShowUnreadCount) {
@@ -193,7 +193,7 @@ void FolderSelectionDialog::slotAddChildFolder()
 void FolderSelectionDialog::collectionCreationResult(KJob *job)
 {
     if (job->error()) {
-        KMessageBox::error(this, i18n("Could not create folder: %1", job->errorString()), i18n("Folder creation failed"));
+        KMessageBox::error(this, i18n("Could not create folder: %1", job->errorString()), i18nc("@title:window", "Folder creation failed"));
     }
 }
 
@@ -224,7 +224,7 @@ QAbstractItemView::SelectionMode FolderSelectionDialog::selectionMode() const
 
 Akonadi::Collection FolderSelectionDialog::selectedCollection() const
 {
-    qDebug() << " d->folderTreeWidget->selectedCollection()" << d->folderTreeWidget->selectedCollection();
+    // qDebug() << " d->folderTreeWidget->selectedCollection()" << d->folderTreeWidget->selectedCollection();
     return d->folderTreeWidget->selectedCollection();
 }
 
@@ -235,10 +235,15 @@ void FolderSelectionDialog::setSelectedCollection(const Akonadi::Collection &col
 
 Akonadi::Collection::List FolderSelectionDialog::selectedCollections() const
 {
-    qDebug() << " selectedCollections " << d->folderTreeWidget->selectedCollections();
+    // qDebug() << " selectedCollections " << d->folderTreeWidget->selectedCollections();
     return d->folderTreeWidget->selectedCollections();
 }
 
+void FolderSelectionDialog::setAccountActivities(Akonadi::AccountActivitiesAbstract *accountActivities)
+{
+    d->folderTreeWidget->setAccountActivities(accountActivities);
+}
+
 static const char myFilterConvertToSieveResultDialogGroupName[] = "FolderSelectionDialog";
 
 void FolderSelectionDialog::readConfig()
