@@ -28,14 +28,12 @@ using namespace MailCommon;
 FolderTreeView::FolderTreeView(QWidget *parent, bool showUnreadCount)
     : Akonadi::EntityTreeView(parent)
 {
-    setProperty("_breeze_force_frame", false);
     init(showUnreadCount);
 }
 
 FolderTreeView::FolderTreeView(KXMLGUIClient *xmlGuiClient, QWidget *parent, bool showUnreadCount)
     : Akonadi::EntityTreeView(xmlGuiClient, parent)
 {
-    setProperty("_breeze_force_frame", false);
     init(showUnreadCount);
 }
 
@@ -68,6 +66,7 @@ void FolderTreeView::disableContextMenuAndExtraColumn()
 
 void FolderTreeView::init(bool showUnreadCount)
 {
+    setProperty("_breeze_force_frame", false);
     setIconSize(QSize(22, 22));
     setUniformRowHeights(true);
     mSortingPolicy = FolderTreeWidget::SortByCurrentColumn;
@@ -202,7 +201,7 @@ void FolderTreeView::slotHeaderContextMenuChangeSortingPolicy(bool)
     QVariant data = act->data();
 
     bool ok;
-    int policy = data.toInt(&ok);
+    const int policy = data.toInt(&ok);
     if (!ok) {
         return;
     }
@@ -249,7 +248,7 @@ void FolderTreeView::slotHeaderContextMenuChangeToolTipDisplayPolicy(bool)
         return;
     }
 
-    QVariant data = act->data();
+    const QVariant data = act->data();
 
     bool ok;
     const int id = data.toInt(&ok);
@@ -266,7 +265,7 @@ void FolderTreeView::slotHeaderContextMenuChangeHeader(bool)
         return;
     }
 
-    QVariant data = act->data();
+    const QVariant data = act->data();
 
     bool ok;
     const int id = data.toInt(&ok);
@@ -292,7 +291,7 @@ void FolderTreeView::slotHeaderContextMenuChangeIconSize(bool)
         return;
     }
 
-    QVariant data = act->data();
+    const QVariant data = act->data();
 
     bool ok;
     const int size = data.toInt(&ok);
@@ -473,7 +472,7 @@ bool FolderTreeView::allowedToEnterFolder(const Akonadi::Collection &collection,
     // parameter (kept in the config file for kmail)
     const int result = KMessageBox::questionTwoActions(const_cast<FolderTreeView *>(this),
                                                        i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-                                                       i18n("Go to Next Unread Message"),
+                                                       i18nc("@title:window", "Go to Next Unread Message"),
                                                        KGuiItem(i18nc("@action:button", "Go To")),
                                                        KGuiItem(i18nc("@action:button", "Do Not Go To")), // defaults
                                                        QStringLiteral(":kmail_AskNextFolder"),
@@ -515,7 +514,7 @@ bool FolderTreeView::isUnreadFolder(const QModelIndex &current, QModelIndex &ind
                         // parameter (kept in the config file for kmail)
                         if (KMessageBox::questionTwoActions(this,
                                                             i18n("<qt>Go to the next unread message in folder <b>%1</b>?</qt>", collection.name()),
-                                                            i18n("Go to Next Unread Message"),
+                                                            i18nc("@title:window", "Go to Next Unread Message"),
                                                             KGuiItem(i18nc("@action:button", "Go To")),
                                                             KGuiItem(i18nc("@action:button", "Do Not Go To")), // defaults
                                                             QStringLiteral(":kmail_AskNextFolder"),
