@@ -17,6 +17,10 @@
 #include <memory>
 namespace Akonadi
 {
+class AccountActivitiesAbstract;
+}
+namespace Akonadi
+{
 class StatisticsProxyModel;
 }
 
@@ -108,6 +112,8 @@ public:
 
     void restoreHeaderState(const QByteArray &data);
 
+    void setAccountActivities(Akonadi::AccountActivitiesAbstract *accountActivities);
+
 protected:
     void changeToolTipsPolicyConfig(ToolTipDisplayPolicy);
 
