@@ -11,6 +11,7 @@
 
 #include <MessageCore/MessageCoreSettings>
 
+#include <Akonadi/AccountActivitiesAbstract>
 #include <Akonadi/AgentInstance>
 #include <Akonadi/AgentManager>
 #include <Akonadi/EntityTreeModel>
@@ -57,6 +58,7 @@ public:
         return false;
     }
 
+    Akonadi::AccountActivitiesAbstract *accountActivities = nullptr;
     QSet<QString> includedMimeTypes;
     Akonadi::MimeTypeChecker checker;
 
@@ -73,7 +75,6 @@ FolderTreeWidgetProxyModel::FolderTreeWidgetProxyModel(QObject *parent, FolderTr
     : Akonadi::EntityRightsFilterModel(parent)
     , d(new FolderTreeWidgetProxyModelPrivate(this))
 {
-    setDynamicSortFilter(true);
     setFilterCaseSensitivity(Qt::CaseInsensitive);
 
     if (option & HideVirtualFolder) {
@@ -178,6 +179,14 @@ bool FolderTreeWidgetProxyModel::filterAcceptsRow(int sourceRow, const QModelInd
     const QModelIndex modelIndex = sourceModel()->index(sourceRow, 0, sourceParent);
 
     const auto collection = sourceModel()->data(modelIndex, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
+    if (d->accountActivities) {
+        const Akonadi::AgentInstance instance = Akonadi::AgentManager::self()->instance(collection.resource());
+        if (instance.activitiesEnabled()) {
+            if (!d->accountActivities->filterAcceptsRow(instance.activities())) {
+                return false;
+            }
+        }
+    }
     if (!d->checker.isWantedCollection(collection)) {
         return false;
     }
@@ -270,4 +279,16 @@ void FolderTreeWidgetProxyModel::addContentMimeTypeInclusionFilter(const QString
     invalidateFilter();
 }
 
+void FolderTreeWidgetProxyModel::setAccountActivities(Akonadi::AccountActivitiesAbstract *accountActivities)
+{
+    if (d->accountActivities) {
+        disconnect(d->accountActivities, &Akonadi::AccountActivitiesAbstract::activitiesChanged, this, &FolderTreeWidgetProxyModel::invalidateFilter);
+    }
+    d->accountActivities = accountActivities;
+    if (d->accountActivities) {
+        connect(d->accountActivities, &Akonadi::AccountActivitiesAbstract::activitiesChanged, this, &FolderTreeWidgetProxyModel::invalidateFilter);
+    }
+    invalidateFilter();
+}
+
 #include "moc_foldertreewidgetproxymodel.cpp"
