@@ -11,7 +11,10 @@
 #include <Akonadi/Collection>
 #include <Akonadi/EntityRightsFilterModel>
 #include <memory>
-
+namespace Akonadi
+{
+class AccountActivitiesAbstract;
+}
 namespace MailCommon
 {
 /**
@@ -23,7 +26,12 @@ class MAILCOMMON_EXPORT FolderTreeWidgetProxyModel : public Akonadi::EntityRight
     Q_OBJECT
 
 public:
-    enum FolderTreeWidgetProxyModelOption { None = 0, HideVirtualFolder = 1, HideSpecificFolder = 2, HideOutboxFolder = 4 };
+    enum FolderTreeWidgetProxyModelOption {
+        None = 0,
+        HideVirtualFolder = 1,
+        HideSpecificFolder = 2,
+        HideOutboxFolder = 4,
+    };
     Q_DECLARE_FLAGS(FolderTreeWidgetProxyModelOptions, FolderTreeWidgetProxyModelOption)
 
     explicit FolderTreeWidgetProxyModel(QObject *parent = nullptr, FolderTreeWidgetProxyModelOptions = FolderTreeWidgetProxyModel::None);
@@ -53,6 +61,8 @@ public:
 
     void setWarningThreshold(qreal threshold);
 
+    void setAccountActivities(Akonadi::AccountActivitiesAbstract *accountActivities);
+
 protected:
     bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
 
