@@ -53,7 +53,8 @@ static const struct {
                          {"Reply-To", kli18n("Reply To")},
                          {"Organization", kli18n("Organization")},
                          {"<date>", kli18n("Date")},
-                         {"<encryption>", kli18n("Encryption")}};
+                         {"<encryption>", kli18n("Encryption")},
+                         {"<attachment>", kli18n("Attachment")}};
 static const int SpecialRuleFieldsCount = sizeof(SpecialRuleFields) / sizeof(*SpecialRuleFields);
 
 //=============================================================================
@@ -364,6 +365,7 @@ void SearchRuleWidget::initFieldList(SearchPatternEdit::SearchPatternEditOptions
     }
 
     mFilterFieldList.append(SpecialRuleFields[Encryption].getLocalizedDisplayName());
+    mFilterFieldList.append(SpecialRuleFields[Attachment].getLocalizedDisplayName());
 
     // these others only represent message headers and you can add to
     // them as you like
@@ -577,10 +579,10 @@ void SearchPatternEdit::initLayout(SearchPatternEditOptions options, SearchModeT
 
     const bool matchAllMessages = (options & MailCommon::SearchPatternEdit::MatchAllMessages);
     //------------the radio buttons
-    mAllRBtn = new QRadioButton(i18n("Match a&ll of the following"), this);
-    mAnyRBtn = new QRadioButton(i18n("Match an&y of the following"), this);
+    mAllRBtn = new QRadioButton(i18nc("@option:radio", "Match a&ll of the following"), this);
+    mAnyRBtn = new QRadioButton(i18nc("@option:radio", "Match an&y of the following"), this);
     if (matchAllMessages) {
-        mAllMessageRBtn = new QRadioButton(i18n("Match all messages"), this);
+        mAllMessageRBtn = new QRadioButton(i18nc("@option:radio", "Match all messages"), this);
     }
 
     mAllRBtn->setObjectName(QLatin1StringView("mAllRBtn"));
