@@ -5,7 +5,7 @@
 */
 
 #pragma once
-
+#include "mailcommon_private_export.h"
 #include "searchpattern.h"
 #include <Akonadi/Item>
 
@@ -18,7 +18,7 @@
  */
 namespace MailCommon
 {
-class SearchRuleString : public SearchRule
+class MAILCOMMON_TESTS_EXPORT SearchRuleString : public SearchRule
 {
 public:
     /**
