@@ -22,8 +22,8 @@ public:
     [[nodiscard]] QStringList attachments() const;
 
 private:
-    void writeConfig();
-    void readConfig();
+    MAILCOMMON_NO_EXPORT void writeConfig();
+    MAILCOMMON_NO_EXPORT void readConfig();
     SnippetSelectAttachmentWidget *const mAttachmentWidget;
 };
 }
