@@ -555,21 +555,21 @@ SnippetsManager::SnippetsManager(KActionCollection *actionCollection, QObject *p
     d->mSelectionModel = new QItemSelectionModel(d->mModel);
     d->mActionCollection = actionCollection;
 
-    d->mAddSnippetAction = new QAction(i18n("Add Snippet..."), this);
+    d->mAddSnippetAction = new QAction(i18nc("@action", "Add Snippet…"), this);
     d->mAddSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    d->mEditSnippetAction = new QAction(i18n("Edit Snippet..."), this);
+    d->mEditSnippetAction = new QAction(i18nc("@action", "Edit Snippet…"), this);
     d->mEditSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("document-properties")));
-    d->mDeleteSnippetAction = new QAction(i18n("Remove Snippet"), this);
+    d->mDeleteSnippetAction = new QAction(i18nc("@action", "Remove Snippet"), this);
     d->mDeleteSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
-    d->mAddSnippetGroupAction = new QAction(i18n("Add Group..."), this);
+    d->mAddSnippetGroupAction = new QAction(i18nc("@action", "Add Group…"), this);
     d->mAddSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("list-add")));
-    d->mEditSnippetGroupAction = new QAction(i18n("Rename Group..."), this);
+    d->mEditSnippetGroupAction = new QAction(i18nc("@action", "Rename Group…"), this);
     d->mEditSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
-    d->mDeleteSnippetGroupAction = new QAction(i18n("Remove Group"), this);
+    d->mDeleteSnippetGroupAction = new QAction(i18nc("@action", "Remove Group"), this);
     d->mDeleteSnippetGroupAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
 
-    d->mInsertSnippetAction = new QAction(i18n("Insert Snippet"), this);
+    d->mInsertSnippetAction = new QAction(i18nc("@action", "Insert Snippet"), this);
     d->mInsertSnippetAction->setIcon(QIcon::fromTheme(QStringLiteral("insert-text")));
 
     connect(d->mSelectionModel, &QItemSelectionModel::selectionChanged, this, [this]() {
