@@ -67,7 +67,7 @@ TagWidget::TagWidget(const QList<KActionCollection *> &actionCollections, QWidge
     connect(d->mTagNameLineEdit, &QLineEdit::textChanged, this, &TagWidget::slotEmitChangeCheck);
 
     // Second row for text color
-    d->mTextColorCheck = new QCheckBox(i18n("Change te&xt color:"), this);
+    d->mTextColorCheck = new QCheckBox(i18nc("@option:check", "Change te&xt color:"), this);
     settings->addWidget(d->mTextColorCheck, 2, 0);
 
     d->mTextColorCombo = new KColorCombo(this);
@@ -75,15 +75,11 @@ TagWidget::TagWidget(const QList<KActionCollection *> &actionCollections, QWidge
     d->mTextColorCombo->setEnabled(false);
 
     connect(d->mTextColorCheck, &QCheckBox::toggled, d->mTextColorCombo, &KColorCombo::setEnabled);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(d->mTextColorCheck, &QCheckBox::stateChanged, this, &TagWidget::slotEmitChangeCheck);
-#else
     connect(d->mTextColorCheck, &QCheckBox::checkStateChanged, this, &TagWidget::slotEmitChangeCheck);
-#endif
     connect(d->mTextColorCombo, &KColorCombo::activated, this, &TagWidget::slotEmitChangeCheck);
 
     // Third row for text background color
-    d->mBackgroundColorCheck = new QCheckBox(i18n("Change &background color:"), this);
+    d->mBackgroundColorCheck = new QCheckBox(i18nc("@option:check", "Change &background color:"), this);
     settings->addWidget(d->mBackgroundColorCheck, 3, 0);
 
     d->mBackgroundColorCombo = new KColorCombo(this);
@@ -91,35 +87,27 @@ TagWidget::TagWidget(const QList<KActionCollection *> &actionCollections, QWidge
     d->mBackgroundColorCombo->setEnabled(false);
 
     connect(d->mBackgroundColorCheck, &QAbstractButton::toggled, d->mBackgroundColorCombo, &QWidget::setEnabled);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(d->mBackgroundColorCheck, &QCheckBox::stateChanged, this, &TagWidget::slotEmitChangeCheck);
-#else
     connect(d->mBackgroundColorCheck, &QCheckBox::checkStateChanged, this, &TagWidget::slotEmitChangeCheck);
-#endif
     connect(d->mBackgroundColorCombo, &KColorCombo::activated, this, &TagWidget::slotEmitChangeCheck);
 
     // Fourth for font selection
-    d->mTextFontCheck = new QCheckBox(i18n("Change fo&nt:"), this);
+    d->mTextFontCheck = new QCheckBox(i18nc("@option:check", "Change fo&nt:"), this);
     settings->addWidget(d->mTextFontCheck, 4, 0);
 
     auto fontLayout = new QVBoxLayout;
     settings->addLayout(fontLayout, 4, 1);
 
-    d->mBoldCheckBox = new QCheckBox(i18n("&Bold"));
+    d->mBoldCheckBox = new QCheckBox(i18nc("@option:check", "&Bold"));
     d->mBoldCheckBox->setEnabled(false);
     fontLayout->addWidget(d->mBoldCheckBox);
 
-    d->mItalicCheckBox = new QCheckBox(i18n("&Italics"));
+    d->mItalicCheckBox = new QCheckBox(i18nc("@option:check", "&Italics"));
     d->mItalicCheckBox->setEnabled(false);
     fontLayout->addWidget(d->mItalicCheckBox);
 
     connect(d->mTextFontCheck, &QAbstractButton::toggled, d->mBoldCheckBox, &QWidget::setEnabled);
     connect(d->mTextFontCheck, &QAbstractButton::toggled, d->mItalicCheckBox, &QWidget::setEnabled);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(d->mTextFontCheck, &QCheckBox::stateChanged, this, &TagWidget::slotEmitChangeCheck);
-#else
     connect(d->mTextFontCheck, &QCheckBox::checkStateChanged, this, &TagWidget::slotEmitChangeCheck);
-#endif
     connect(d->mBoldCheckBox, &QAbstractButton::toggled, this, &TagWidget::slotEmitChangeCheck);
     connect(d->mItalicCheckBox, &QAbstractButton::toggled, this, &TagWidget::slotEmitChangeCheck);
 
@@ -153,13 +141,9 @@ TagWidget::TagWidget(const QList<KActionCollection *> &actionCollections, QWidge
     }
 
     // Seventh for Toolbar checkbox
-    d->mInToolbarCheck = new QCheckBox(i18n("Enable &toolbar button"), this);
+    d->mInToolbarCheck = new QCheckBox(i18nc("@option:check", "Enable &toolbar button"), this);
     settings->addWidget(d->mInToolbarCheck, 7, 0);
-#if QT_VERSION < QT_VERSION_CHECK(6, 7, 0)
-    connect(d->mInToolbarCheck, &QCheckBox::stateChanged, this, &TagWidget::slotEmitChangeCheck);
-#else
     connect(d->mInToolbarCheck, &QCheckBox::checkStateChanged, this, &TagWidget::slotEmitChangeCheck);
-#endif
 }
 
 TagWidget::~TagWidget() = default;
