@@ -204,7 +204,7 @@ void RedirectDialog::accept()
 {
     const QString editTo = d->mEditTo->resend();
     if (editTo.isEmpty()) {
-        KMessageBox::error(this, i18n("You cannot redirect the message without an address."), i18n("Empty Redirection Address"));
+        KMessageBox::error(this, i18n("You cannot redirect the message without an address."), i18nc("@title:window", "Empty Redirection Address"));
     } else {
         done(QDialog::Accepted);
     }
